{% extends 'bootstrap-italia-base.html' %}
{% load i18n %}

{% block centered_container %}
    <h4>{% trans "Internal Error 500" %}</h4>
    <p>{% trans "This service has encourrend and unexpected error" %}</p>
</div>
{% endblock centered_container %}
